# arpes.pipelines module

Implements some pipelines for basic tasks.

**arpes.pipelines.convert\_scan\_to\_kspace(data, \*args,**kwargs)\*\*

**arpes.pipelines.convert\_scan\_to\_kspace\_no\_corr(data,
\*args,**kwargs)\*\*

**arpes.pipelines.tr\_prep\_scan\_ammeter(data, \*args,**kwargs)\*\*

**arpes.pipelines.tr\_prep\_scan\_simple(data, \*args,**kwargs)\*\*

**arpes.pipelines.convert\_mc\_map\_to\_kspace\_fft\_filter(data,
\*args,**kwargs)\*\*

**arpes.pipelines.prep\_for\_d2(data, \*args,**kwargs)\*\*
